==> ejc-analysis-impl-3.0.0-20230719.093208-86-sources.jar: com/ejianc/business/analysis/bean/CostEntity.java <==
package com.ejianc.business.analysis.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 薪酬及三公费用占现场经费比例分析
 * 
 * @author generator
 * 
 */
 @TableName("ejc_analysis_cost")
public class CostEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_code")
    private String orgCode; // 所属组织编码
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="two_org_id")
    private Long twoOrgId; // 二级组织id
    @TableField(value="two_org_code")
    private String twoOrgCode; // 二级组织编码
    @TableField(value="two_org_name")
    private String twoOrgName; // 二级组织名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_status")
    private Integer projectStatus; // 项目状态
    @TableField(value="reporting_month")
    private String reportingMonth; // 报表日期
    @TableField(value="xc_mny")
    private BigDecimal xcMny; // 薪酬（五险一金）
    @TableField(value="bg_mny")
    private BigDecimal bgMny; // 办公费用
    @TableField(value="cl_mny")
    private BigDecimal clMny; // 差旅费用
    @TableField(value="zd_mny")
    private BigDecimal zdMny; // 招待费用
    @TableField(value="qt_mny")
    private BigDecimal qtMny; // 其他
    @TableField(value="mny")
    private BigDecimal mny; // 合计
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_create_time")
    private Date projectCreateTime; // 项目创建日期
    @TableField(value="cost_analysis_create_time")
    private Date costAnalysisCreateTime; // 月度分析报告创建时间
    @TableField(value="org_status_order")
    private Integer orgStatusOrder; // 二级组织排序
    @TableField(value="code")
    private String code; // 费用编码

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }
    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }
    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Integer getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Integer projectStatus) {
        this.projectStatus = projectStatus;
    }
    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }
    public BigDecimal getXcMny() {
        return xcMny;
    }

    public void setXcMny(BigDecimal xcMny) {
        this.xcMny = xcMny;
    }
    public BigDecimal getBgMny() {
        return bgMny;
    }

    public void setBgMny(BigDecimal bgMny) {
        this.bgMny = bgMny;
    }
    public BigDecimal getClMny() {
        return clMny;
    }

    public void setClMny(BigDecimal clMny) {
        this.clMny = clMny;
    }
    public BigDecimal getZdMny() {
        return zdMny;
    }

    public void setZdMny(BigDecimal zdMny) {
        this.zdMny = zdMny;
    }
    public BigDecimal getQtMny() {
        return qtMny;
    }

    public void setQtMny(BigDecimal qtMny) {
        this.qtMny = qtMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }
    public Date getCostAnalysisCreateTime() {
        return costAnalysisCreateTime;
    }

    public void setCostAnalysisCreateTime(Date costAnalysisCreateTime) {
        this.costAnalysisCreateTime = costAnalysisCreateTime;
    }
    public Integer getOrgStatusOrder() {
        return orgStatusOrder;
    }

    public void setOrgStatusOrder(Integer orgStatusOrder) {
        this.orgStatusOrder = orgStatusOrder;
    }
    
}

==> ejc-analysis-impl-3.0.0-20240429.070505-168-sources.jar: com/ejianc/business/analysis/bean/CostEntity.java <==
package com.ejianc.business.analysis.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 薪酬及三公费用占现场经费比例分析
 * 
 * @author generator
 * 
 */
 @TableName("ejc_analysis_cost")
public class CostEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_code")
    private String orgCode; // 所属组织编码
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="two_org_id")
    private Long twoOrgId; // 二级组织id
    @TableField(value="two_org_code")
    private String twoOrgCode; // 二级组织编码
    @TableField(value="two_org_name")
    private String twoOrgName; // 二级组织名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_status")
    private Integer projectStatus; // 项目状态
    @TableField(value="reporting_month")
    private String reportingMonth; // 报表日期
    @TableField(value="xc_mny")
    private BigDecimal xcMny; // 薪酬（五险一金）
    @TableField(value="bg_mny")
    private BigDecimal bgMny; // 办公费用
    @TableField(value="cl_mny")
    private BigDecimal clMny; // 差旅费用
    @TableField(value="zd_mny")
    private BigDecimal zdMny; // 招待费用
    @TableField(value="qt_mny")
    private BigDecimal qtMny; // 其他
    @TableField(value="mny")
    private BigDecimal mny; // 合计
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_create_time")
    private Date projectCreateTime; // 项目创建日期
    @TableField(value="cost_analysis_create_time")
    private Date costAnalysisCreateTime; // 月度分析报告创建时间
    @TableField(value="org_status_order")
    private Integer orgStatusOrder; // 二级组织排序
    @TableField(value="code")
    private String code; // 费用编码
    @TableField(value="short_name")
    private String shortName;//组织简称
    public String getShortName() {
        return shortName;
    }

    public void setShortName(String shortName) {
        this.shortName = shortName;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }
    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }
    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Integer getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Integer projectStatus) {
        this.projectStatus = projectStatus;
    }
    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }
    public BigDecimal getXcMny() {
        return xcMny;
    }

    public void setXcMny(BigDecimal xcMny) {
        this.xcMny = xcMny;
    }
    public BigDecimal getBgMny() {
        return bgMny;
    }

    public void setBgMny(BigDecimal bgMny) {
        this.bgMny = bgMny;
    }
    public BigDecimal getClMny() {
        return clMny;
    }

    public void setClMny(BigDecimal clMny) {
        this.clMny = clMny;
    }
    public BigDecimal getZdMny() {
        return zdMny;
    }

    public void setZdMny(BigDecimal zdMny) {
        this.zdMny = zdMny;
    }
    public BigDecimal getQtMny() {
        return qtMny;
    }

    public void setQtMny(BigDecimal qtMny) {
        this.qtMny = qtMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }
    public Date getCostAnalysisCreateTime() {
        return costAnalysisCreateTime;
    }

    public void setCostAnalysisCreateTime(Date costAnalysisCreateTime) {
        this.costAnalysisCreateTime = costAnalysisCreateTime;
    }
    public Integer getOrgStatusOrder() {
        return orgStatusOrder;
    }

    public void setOrgStatusOrder(Integer orgStatusOrder) {
        this.orgStatusOrder = orgStatusOrder;
    }
    
}
